public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
* [edk2-devel] [PATCH 1/1] MdeModulePkg: Fix typos in Bus and Core
@ 2023-11-21  2:07 Page Chen via groups.io
  2023-11-21 16:16 ` Laszlo Ersek
  0 siblings, 1 reply; 3+ messages in thread
From: Page Chen via groups.io @ 2023-11-21  2:07 UTC (permalink / raw)
  To: devel; +Cc: Page Chen, Liming Gao, Ray Ni, Andrew Fish

begining -> beginning
Cabability -> Capability
CHNAGED -> CHANGED
compatability -> compatibility
concident -> coincident
correspoding -> corresponding
defered -> deferred
Dispacher -> Dispatcher
execuing -> executing
exhausive -> exhaustive
functio -> function
funtion -> function
funtions -> functions
notificaiton -> notification
Regsitered -> Registered
SUCESS -> SUCCESS
sucessfully -> successfully
writting -> writing

Signed-off-by: Page Chen <paiching_chen@apple.com>
Cc: Liming Gao <gaoliming@byosoft.com.cn>
Cc: Ray Ni <ray.ni@intel.com>
Cc: Andrew Fish <afish@apple.com>
---
 .../Bus/Ata/AhciPei/AhciPeiStorageSecurity.c   |  2 +-
 .../Bus/Ata/AhciPei/AhciPeiStorageSecurity.h   |  2 +-
 .../Bus/Isa/Ps2KeyboardDxe/Ps2KbdTextIn.c      | 18 +++++++++---------
 .../Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.h       |  4 ++--
 .../Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.c  | 10 +++++-----
 .../Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.h  |  8 ++++----
 .../Bus/Pci/NvmExpressPei/NvmExpressPeiHci.c   |  4 ++--
 .../Bus/Pci/NvmExpressPei/NvmExpressPeiHci.h   |  4 ++--
 .../NvmExpressPeiStorageSecurity.c             |  2 +-
 .../NvmExpressPeiStorageSecurity.h             |  2 +-
 .../Bus/Pci/PciBusDxe/PciOptionRomSupport.c    |  4 ++--
 .../Bus/Pci/PciBusDxe/PciOptionRomSupport.h    |  2 +-
 MdeModulePkg/Bus/Pci/XhciDxe/XhciReg.h         |  2 +-
 MdeModulePkg/Bus/Pci/XhciDxe/XhciSched.c       |  2 +-
 MdeModulePkg/Bus/Pci/XhciPei/XhciSched.c       |  2 +-
 MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.c         | 18 +++++++++---------
 MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.h         |  4 ++--
 MdeModulePkg/Core/Dxe/Dispatcher/Dispatcher.c  |  2 +-
 MdeModulePkg/Core/Dxe/DxeMain.h                |  8 ++++----
 MdeModulePkg/Core/Dxe/FwVol/FwVolRead.c        |  2 +-
 MdeModulePkg/Core/Dxe/Hand/Notify.c            |  2 +-
 MdeModulePkg/Core/Dxe/Image/Image.c            |  2 +-
 MdeModulePkg/Core/Dxe/Mem/Page.c               |  6 +++---
 .../SectionExtraction/CoreSectionExtraction.c  |  6 +++---
 MdeModulePkg/Core/DxeIplPeim/DxeLoad.c         |  4 ++--
 MdeModulePkg/Core/Pei/PeiMain.h                |  2 +-
 26 files changed, 62 insertions(+), 62 deletions(-)

diff --git a/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.c b/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.c
index 40e042082cde..6381c371698f 100644
--- a/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.c
+++ b/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.c
@@ -302,7 +302,7 @@ AhciStorageSecurityReceiveData (
 
   If the security protocol command completes without an error, the function shall
   return EFI_SUCCESS. If the security protocol command completes with an error,
-  the functio shall return EFI_DEVICE_ERROR.
+  the function shall return EFI_DEVICE_ERROR.
 
   @param[in] This              The PPI instance pointer.
   @param[in] DeviceIndex       The ID of the device.
diff --git a/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.h b/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.h
index a13533ea57ea..8bc367da21d8 100644
--- a/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.h
+++ b/MdeModulePkg/Bus/Ata/AhciPei/AhciPeiStorageSecurity.h
@@ -190,7 +190,7 @@ AhciStorageSecurityReceiveData (
 
   If the security protocol command completes without an error, the function shall
   return EFI_SUCCESS. If the security protocol command completes with an error,
-  the functio shall return EFI_DEVICE_ERROR.
+  the function shall return EFI_DEVICE_ERROR.
 
   @param[in] This              The PPI instance pointer.
   @param[in] DeviceIndex       The ID of the device.
diff --git a/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdTextIn.c b/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdTextIn.c
index b1ab17af3788..535f234916c0 100644
--- a/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdTextIn.c
+++ b/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdTextIn.c
@@ -81,7 +81,7 @@ PushEfikeyBufTail (
 /**
   Judge whether is a registered key
 
-  @param RegsiteredData       A pointer to a buffer that is filled in with the keystroke
+  @param RegisteredData       A pointer to a buffer that is filled in with the keystroke
                               state data for the key that was registered.
   @param InputData            A pointer to a buffer that is filled in with the keystroke
                               state data for the key that was pressed.
@@ -92,15 +92,15 @@ PushEfikeyBufTail (
 **/
 BOOLEAN
 IsKeyRegistered (
-  IN EFI_KEY_DATA  *RegsiteredData,
+  IN EFI_KEY_DATA  *RegisteredData,
   IN EFI_KEY_DATA  *InputData
   )
 
 {
-  ASSERT (RegsiteredData != NULL && InputData != NULL);
+  ASSERT (RegisteredData != NULL && InputData != NULL);
 
-  if ((RegsiteredData->Key.ScanCode    != InputData->Key.ScanCode) ||
-      (RegsiteredData->Key.UnicodeChar != InputData->Key.UnicodeChar))
+  if ((RegisteredData->Key.ScanCode    != InputData->Key.ScanCode) ||
+      (RegisteredData->Key.UnicodeChar != InputData->Key.UnicodeChar))
   {
     return FALSE;
   }
@@ -108,14 +108,14 @@ IsKeyRegistered (
   //
   // Assume KeyShiftState/KeyToggleState = 0 in Registered key data means these state could be ignored.
   //
-  if ((RegsiteredData->KeyState.KeyShiftState != 0) &&
-      (RegsiteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState))
+  if ((RegisteredData->KeyState.KeyShiftState != 0) &&
+      (RegisteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState))
   {
     return FALSE;
   }
 
-  if ((RegsiteredData->KeyState.KeyToggleState != 0) &&
-      (RegsiteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState))
+  if ((RegisteredData->KeyState.KeyToggleState != 0) &&
+      (RegisteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState))
   {
     return FALSE;
   }
diff --git a/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.h b/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.h
index ca1dd9b2c2c6..38a649dab00c 100644
--- a/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.h
+++ b/MdeModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.h
@@ -532,7 +532,7 @@ PushEfikeyBufTail (
 /**
   Judge whether is a registered key
 
-  @param RegsiteredData       A pointer to a buffer that is filled in with the keystroke
+  @param RegisteredData       A pointer to a buffer that is filled in with the keystroke
                               state data for the key that was registered.
   @param InputData            A pointer to a buffer that is filled in with the keystroke
                               state data for the key that was pressed.
@@ -543,7 +543,7 @@ PushEfikeyBufTail (
 **/
 BOOLEAN
 IsKeyRegistered (
-  IN EFI_KEY_DATA  *RegsiteredData,
+  IN EFI_KEY_DATA  *RegisteredData,
   IN EFI_KEY_DATA  *InputData
   );
 
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.c b/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.c
index b6ed7f7031b3..ee8bd1408e62 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.c
+++ b/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.c
@@ -358,7 +358,7 @@ NvmeFlush (
 }
 
 /**
-  Nonblocking I/O callback funtion when the event is signaled.
+  Nonblocking I/O callback function when the event is signaled.
 
   @param[in]  Event     The Event this notify function registered to.
   @param[in]  Context   Pointer to the context data registered to the
@@ -1100,7 +1100,7 @@ NvmeBlockIoReadBlocks (
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing the write.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current device.
+  @retval EFI_MEDIA_CHANGED     The MediaId does not matched the current device.
   @retval EFI_BAD_BUFFER_SIZE   The Buffer was not a multiple of the block size of the device.
   @retval EFI_INVALID_PARAMETER The write request contains LBAs that are not valid,
                                 or the buffer is not on proper alignment.
@@ -1214,7 +1214,7 @@ NvmeBlockIoFlushBlocks (
 
   @param[in]  This                 Indicates a pointer to the calling context.
   @param[in]  ExtendedVerification Indicates that the driver may perform a more
-                                   exhausive verfication operation of the
+                                   exhaustive verification operation of the
                                    device during reset.
 
   @retval EFI_SUCCESS          The device was reset.
@@ -1408,7 +1408,7 @@ NvmeBlockIoReadBlocksEx (
                                 the Event is NULL.
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current
+  @retval EFI_MEDIA_CHANGED     The MediaId does not matched the current
                                 device.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing
                                 the write.
@@ -1511,7 +1511,7 @@ NvmeBlockIoWriteBlocksEx (
                                NULL.
                                All outstanding data was written correctly to
                                the device if the Event is NULL.
-  @retval EFI_DEVICE_ERROR     The device reported an error while writting back
+  @retval EFI_DEVICE_ERROR     The device reported an error while writing back
                                the data.
   @retval EFI_WRITE_PROTECTED  The device cannot be written to.
   @retval EFI_NO_MEDIA         There is no media in the device.
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.h b/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.h
index 8cad15efd33a..5213448e41fa 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.h
+++ b/MdeModulePkg/Bus/Pci/NvmExpressDxe/NvmExpressBlockIo.h
@@ -70,7 +70,7 @@ NvmeBlockIoReadBlocks (
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing the write.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current device.
+  @retval EFI_MEDIA_CHANGED     The MediaId does not matched the current device.
   @retval EFI_BAD_BUFFER_SIZE   The Buffer was not a multiple of the block size of the device.
   @retval EFI_INVALID_PARAMETER The write request contains LBAs that are not valid,
                                 or the buffer is not on proper alignment.
@@ -107,7 +107,7 @@ NvmeBlockIoFlushBlocks (
 
   @param[in]  This                 Indicates a pointer to the calling context.
   @param[in]  ExtendedVerification Indicates that the driver may perform a more
-                                   exhausive verfication operation of the
+                                   exhaustive verification operation of the
                                    device during reset.
 
   @retval EFI_SUCCESS          The device was reset.
@@ -195,7 +195,7 @@ NvmeBlockIoReadBlocksEx (
                                 the Event is NULL.
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current
+  @retval EFI_MEDIA_CHANGED     The MediaId does not matched the current
                                 device.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing
                                 the write.
@@ -234,7 +234,7 @@ NvmeBlockIoWriteBlocksEx (
                                NULL.
                                All outstanding data was written correctly to
                                the device if the Event is NULL.
-  @retval EFI_DEVICE_ERROR     The device reported an error while writting back
+  @retval EFI_DEVICE_ERROR     The device reported an error while writing back
                                the data.
   @retval EFI_WRITE_PROTECTED  The device cannot be written to.
   @retval EFI_NO_MEDIA         There is no media in the device.
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.c b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.c
index fc7b684940d9..966bdc9b95b8 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.c
+++ b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.c
@@ -17,7 +17,7 @@
   @param[in] MmioAddr         Source: MMIO address.
   @param[in] Size             Size for read.
 
-  @retval EFI_SUCCESS         MMIO read sucessfully.
+  @retval EFI_SUCCESS         MMIO read successfully.
 
 **/
 EFI_STATUS
@@ -69,7 +69,7 @@ NvmeMmioRead (
   @param[in] MemBuffer       Source: Memory address.
   @param[in] Size            Size for write.
 
-  @retval EFI_SUCCESS        MMIO write sucessfully.
+  @retval EFI_SUCCESS        MMIO write successfully.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.h b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.h
index a6bec510f0c8..649500db1bf6 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.h
+++ b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiHci.h
@@ -58,7 +58,7 @@ enum {
   @param[in] MmioAddr         Source: MMIO address.
   @param[in] Size             Size for read.
 
-  @retval EFI_SUCCESS         MMIO read sucessfully.
+  @retval EFI_SUCCESS         MMIO read successfully.
 
 **/
 EFI_STATUS
@@ -75,7 +75,7 @@ NvmeMmioRead (
   @param[in] MemBuffer       Source: Memory address.
   @param[in] Size            Size for write.
 
-  @retval EFI_SUCCESS        MMIO write sucessfully.
+  @retval EFI_SUCCESS        MMIO write successfully.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.c b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.c
index d45487efed95..5b0d5bda1727 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.c
+++ b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.c
@@ -347,7 +347,7 @@ NvmeStorageSecurityReceiveData (
 
   If the security protocol command completes without an error, the function shall
   return EFI_SUCCESS. If the security protocol command completes with an error,
-  the functio shall return EFI_DEVICE_ERROR.
+  the function shall return EFI_DEVICE_ERROR.
 
   @param[in] This              The PPI instance pointer.
   @param[in] DeviceIndex       The ID of the device.
diff --git a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.h b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.h
index 16351882efe2..93fadd18f96d 100644
--- a/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.h
+++ b/MdeModulePkg/Bus/Pci/NvmExpressPei/NvmExpressPeiStorageSecurity.h
@@ -190,7 +190,7 @@ NvmeStorageSecurityReceiveData (
 
   If the security protocol command completes without an error, the function shall
   return EFI_SUCCESS. If the security protocol command completes with an error,
-  the functio shall return EFI_DEVICE_ERROR.
+  the function shall return EFI_DEVICE_ERROR.
 
   @param[in] This              The PPI instance pointer.
   @param[in] DeviceIndex       The ID of the device.
diff --git a/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.c b/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.c
index bd5ace18f6e4..5c7ef167b196 100644
--- a/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.c
+++ b/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.c
@@ -1,5 +1,5 @@
 /** @file
-  PCI Rom supporting funtions implementation for PCI Bus module.
+  PCI Rom supporting functions implementation for PCI Bus module.
 
 Copyright (c) 2006 - 2019, Intel Corporation. All rights reserved.<BR>
 SPDX-License-Identifier: BSD-2-Clause-Patent
@@ -371,7 +371,7 @@ ContainEfiImage (
   @param RomBase   Base address of Option Rom.
 
   @retval EFI_OUT_OF_RESOURCES No enough memory to hold image.
-  @retval EFI_SUCESS           Successfully loaded Option Rom.
+  @retval EFI_SUCCESS          Successfully loaded Option Rom.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.h b/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.h
index 16998a422e16..0ddad05b8572 100644
--- a/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.h
+++ b/MdeModulePkg/Bus/Pci/PciBusDxe/PciOptionRomSupport.h
@@ -91,7 +91,7 @@ GetOpRomInfo (
   @param RomBase   Base address of Option Rom.
 
   @retval EFI_OUT_OF_RESOURCES No enough memory to hold image.
-  @retval EFI_SUCESS           Successfully loaded Option Rom.
+  @retval EFI_SUCCESS          Successfully loaded Option Rom.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Bus/Pci/XhciDxe/XhciReg.h b/MdeModulePkg/Bus/Pci/XhciDxe/XhciReg.h
index 63bcae897499..ff24185c5bfa 100644
--- a/MdeModulePkg/Bus/Pci/XhciDxe/XhciReg.h
+++ b/MdeModulePkg/Bus/Pci/XhciDxe/XhciReg.h
@@ -144,7 +144,7 @@ typedef union {
 } XHC_HCCPARAMS;
 
 //
-// xHCI Supported Protocol Cabability
+// xHCI Supported Protocol Capability
 //
 typedef struct {
   UINT8    CapId;
diff --git a/MdeModulePkg/Bus/Pci/XhciDxe/XhciSched.c b/MdeModulePkg/Bus/Pci/XhciDxe/XhciSched.c
index 05528a478baf..79da5a9e1210 100644
--- a/MdeModulePkg/Bus/Pci/XhciDxe/XhciSched.c
+++ b/MdeModulePkg/Bus/Pci/XhciDxe/XhciSched.c
@@ -2047,7 +2047,7 @@ XhcCheckNewEvent (
 
   EvtRing->EventRingDequeue++;
   //
-  // If the dequeue pointer is beyond the ring, then roll-back it to the begining of the ring.
+  // If the dequeue pointer is beyond the ring, then roll-back it to the beginning of the ring.
   //
   if ((UINTN)EvtRing->EventRingDequeue >= ((UINTN)EvtRing->EventRingSeg0 + sizeof (TRB_TEMPLATE) * EvtRing->TrbNumber)) {
     EvtRing->EventRingDequeue = EvtRing->EventRingSeg0;
diff --git a/MdeModulePkg/Bus/Pci/XhciPei/XhciSched.c b/MdeModulePkg/Bus/Pci/XhciPei/XhciSched.c
index 53272f62dd3c..1ffed47d9a13 100644
--- a/MdeModulePkg/Bus/Pci/XhciPei/XhciSched.c
+++ b/MdeModulePkg/Bus/Pci/XhciPei/XhciSched.c
@@ -2574,7 +2574,7 @@ XhcPeiCheckNewEvent (
 
   EvtRing->EventRingDequeue++;
   //
-  // If the dequeue pointer is beyond the ring, then roll-back it to the begining of the ring.
+  // If the dequeue pointer is beyond the ring, then roll-back it to the beginning of the ring.
   //
   if ((UINTN)EvtRing->EventRingDequeue >= ((UINTN)EvtRing->EventRingSeg0 + sizeof (TRB_TEMPLATE) * EvtRing->TrbNumber)) {
     EvtRing->EventRingDequeue = EvtRing->EventRingSeg0;
diff --git a/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.c b/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.c
index e889f422bbf7..1e68a45e7422 100644
--- a/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.c
+++ b/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.c
@@ -875,7 +875,7 @@ KbdFreeNotifyList (
 /**
   Check whether the pressed key matches a registered key or not.
 
-  @param  RegsiteredData    A pointer to keystroke data for the key that was registered.
+  @param  RegisteredData    A pointer to keystroke data for the key that was registered.
   @param  InputData         A pointer to keystroke data for the key that was pressed.
 
   @retval TRUE              Key pressed matches a registered key.
@@ -884,14 +884,14 @@ KbdFreeNotifyList (
 **/
 BOOLEAN
 IsKeyRegistered (
-  IN EFI_KEY_DATA  *RegsiteredData,
+  IN EFI_KEY_DATA  *RegisteredData,
   IN EFI_KEY_DATA  *InputData
   )
 {
-  ASSERT (RegsiteredData != NULL && InputData != NULL);
+  ASSERT (RegisteredData != NULL && InputData != NULL);
 
-  if ((RegsiteredData->Key.ScanCode    != InputData->Key.ScanCode) ||
-      (RegsiteredData->Key.UnicodeChar != InputData->Key.UnicodeChar))
+  if ((RegisteredData->Key.ScanCode    != InputData->Key.ScanCode) ||
+      (RegisteredData->Key.UnicodeChar != InputData->Key.UnicodeChar))
   {
     return FALSE;
   }
@@ -899,14 +899,14 @@ IsKeyRegistered (
   //
   // Assume KeyShiftState/KeyToggleState = 0 in Registered key data means these state could be ignored.
   //
-  if ((RegsiteredData->KeyState.KeyShiftState != 0) &&
-      (RegsiteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState))
+  if ((RegisteredData->KeyState.KeyShiftState != 0) &&
+      (RegisteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState))
   {
     return FALSE;
   }
 
-  if ((RegsiteredData->KeyState.KeyToggleState != 0) &&
-      (RegsiteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState))
+  if ((RegisteredData->KeyState.KeyToggleState != 0) &&
+      (RegisteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState))
   {
     return FALSE;
   }
diff --git a/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.h b/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.h
index a9dfeafd6f10..1a7eb9de5db7 100644
--- a/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.h
+++ b/MdeModulePkg/Bus/Usb/UsbKbDxe/EfiKey.h
@@ -574,7 +574,7 @@ KbdFreeNotifyList (
 /**
   Check whether the pressed key matches a registered key or not.
 
-  @param  RegsiteredData    A pointer to keystroke data for the key that was registered.
+  @param  RegisteredData    A pointer to keystroke data for the key that was registered.
   @param  InputData         A pointer to keystroke data for the key that was pressed.
 
   @retval TRUE              Key pressed matches a registered key.
@@ -583,7 +583,7 @@ KbdFreeNotifyList (
 **/
 BOOLEAN
 IsKeyRegistered (
-  IN EFI_KEY_DATA  *RegsiteredData,
+  IN EFI_KEY_DATA  *RegisteredData,
   IN EFI_KEY_DATA  *InputData
   );
 
diff --git a/MdeModulePkg/Core/Dxe/Dispatcher/Dispatcher.c b/MdeModulePkg/Core/Dxe/Dispatcher/Dispatcher.c
index cf9d55687766..ef44f0fa4495 100644
--- a/MdeModulePkg/Core/Dxe/Dispatcher/Dispatcher.c
+++ b/MdeModulePkg/Core/Dxe/Dispatcher/Dispatcher.c
@@ -56,7 +56,7 @@ LIST_ENTRY  mFvHandleList = INITIALIZE_LIST_HEAD_VARIABLE (mFvHandleList);
 EFI_LOCK  mDispatcherLock = EFI_INITIALIZE_LOCK_VARIABLE (TPL_HIGH_LEVEL);
 
 //
-// Flag for the DXE Dispacher.  TRUE if dispatcher is execuing.
+// Flag for the DXE Dispatcher.  TRUE if dispatcher is executing.
 //
 BOOLEAN  gDispatcherRunning = FALSE;
 
diff --git a/MdeModulePkg/Core/Dxe/DxeMain.h b/MdeModulePkg/Core/Dxe/DxeMain.h
index 43daa037be44..6082d20e746c 100644
--- a/MdeModulePkg/Core/Dxe/DxeMain.h
+++ b/MdeModulePkg/Core/Dxe/DxeMain.h
@@ -2205,7 +2205,7 @@ DxeMainUefiDecompressGetInfo (
   implementation. It is the caller's responsibility to allocate and free the
   Destination and Scratch buffers.
   If the compressed source data specified by Source and SourceSize is
-  sucessfully decompressed into Destination, then EFI_SUCCESS is returned. If
+  successfully decompressed into Destination, then EFI_SUCCESS is returned. If
   the compressed source data specified by Source and SourceSize is not in a
   valid compressed data format, then EFI_INVALID_PARAMETER is returned.
 
@@ -2252,7 +2252,7 @@ DxeMainUefiDecompress (
 
   @retval EFI_SUCCESS            The section stream is created successfully.
   @retval EFI_OUT_OF_RESOURCES   memory allocation failed.
-  @retval EFI_INVALID_PARAMETER  Section stream does not end concident with end
+  @retval EFI_INVALID_PARAMETER  Section stream does not end coincident with end
                                  of last section.
 
 **/
@@ -2342,9 +2342,9 @@ GetSection (
   @param  FreeStreamBuffer       TRUE - Need to free stream buffer;
                                  FALSE - No need to free stream buffer.
 
-  @retval EFI_SUCCESS            The section stream is closed sucessfully.
+  @retval EFI_SUCCESS            The section stream is closed successfully.
   @retval EFI_OUT_OF_RESOURCES   Memory allocation failed.
-  @retval EFI_INVALID_PARAMETER  Section stream does not end concident with end
+  @retval EFI_INVALID_PARAMETER  Section stream does not end coincident with end
                                  of last section.
 
 **/
diff --git a/MdeModulePkg/Core/Dxe/FwVol/FwVolRead.c b/MdeModulePkg/Core/Dxe/FwVol/FwVolRead.c
index 2ff22c93aad4..b148e90b3045 100644
--- a/MdeModulePkg/Core/Dxe/FwVol/FwVolRead.c
+++ b/MdeModulePkg/Core/Dxe/FwVol/FwVolRead.c
@@ -524,7 +524,7 @@ FvReadFileSection (
   }
 
   //
-  // Close of stream defered to close of FfsHeader list to allow SEP to cache data
+  // Close of stream deferred to close of FfsHeader list to allow SEP to cache data
   //
 
 Done:
diff --git a/MdeModulePkg/Core/Dxe/Hand/Notify.c b/MdeModulePkg/Core/Dxe/Hand/Notify.c
index a6e20cad236f..414ac5963e29 100644
--- a/MdeModulePkg/Core/Dxe/Hand/Notify.c
+++ b/MdeModulePkg/Core/Dxe/Hand/Notify.c
@@ -130,7 +130,7 @@ CoreRegisterProtocolNotify (
       ProtNotify->Protocol       = ProtEntry;
       ProtNotify->Event          = Event;
       //
-      // start at the begining
+      // start at the beginning
       //
       ProtNotify->Position = &ProtEntry->Protocols;
 
diff --git a/MdeModulePkg/Core/Dxe/Image/Image.c b/MdeModulePkg/Core/Dxe/Image/Image.c
index 6bc3a549ae5e..02b6635e79a9 100644
--- a/MdeModulePkg/Core/Dxe/Image/Image.c
+++ b/MdeModulePkg/Core/Dxe/Image/Image.c
@@ -66,7 +66,7 @@ LOADED_IMAGE_PRIVATE_DATA  mCorePrivateImage = {
 };
 //
 // The field is define for Loading modules at fixed address feature to tracker the PEI code
-// memory range usage. It is a bit mapped array in which every bit indicates the correspoding memory page
+// memory range usage. It is a bit mapped array in which every bit indicates the corresponding memory page
 // available or not.
 //
 GLOBAL_REMOVE_IF_UNREFERENCED    UINT64  *mDxeCodeMemoryRangeUsageBitMap = NULL;
diff --git a/MdeModulePkg/Core/Dxe/Mem/Page.c b/MdeModulePkg/Core/Dxe/Mem/Page.c
index 6497af573353..fadbd64d602e 100644
--- a/MdeModulePkg/Core/Dxe/Mem/Page.c
+++ b/MdeModulePkg/Core/Dxe/Mem/Page.c
@@ -192,12 +192,12 @@ CoreAddRange (
   mMemoryMapKey += 1;
 
   //
-  // UEFI 2.0 added an event group for notificaiton on memory map changes.
+  // UEFI 2.0 added an event group for notification on memory map changes.
   // So we need to signal this Event Group every time the memory map changes.
-  // If we are in EFI 1.10 compatability mode no event groups will be
+  // If we are in EFI 1.10 compatibility mode no event groups will be
   // found and nothing will happen we we call this function. These events
   // will get signaled but since a lock is held around the call to this
-  // function the notificaiton events will only be called after this function
+  // function the notification events will only be called after this function
   // returns and the lock is released.
   //
   CoreNotifySignalList (&gEfiEventMemoryMapChangeGuid);
diff --git a/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c b/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
index 2152833ff639..e7fd60f99efd 100644
--- a/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
+++ b/MdeModulePkg/Core/Dxe/SectionExtraction/CoreSectionExtraction.c
@@ -409,7 +409,7 @@ OpenSectionStreamEx (
 
   @retval EFI_SUCCESS            The section stream is created successfully.
   @retval EFI_OUT_OF_RESOURCES   memory allocation failed.
-  @retval EFI_INVALID_PARAMETER  Section stream does not end concident with end
+  @retval EFI_INVALID_PARAMETER  Section stream does not end coincident with end
                                  of last section.
 
 **/
@@ -1406,9 +1406,9 @@ FreeChildNode (
   @param  FreeStreamBuffer       TRUE - Need to free stream buffer;
                                  FALSE - No need to free stream buffer.
 
-  @retval EFI_SUCCESS            The section stream is closed sucessfully.
+  @retval EFI_SUCCESS            The section stream is closed successfully.
   @retval EFI_OUT_OF_RESOURCES   Memory allocation failed.
-  @retval EFI_INVALID_PARAMETER  Section stream does not end concident with end
+  @retval EFI_INVALID_PARAMETER  Section stream does not end coincident with end
                                  of last section.
 
 **/
diff --git a/MdeModulePkg/Core/Pei/PeiMain.h b/MdeModulePkg/Core/Pei/PeiMain.h
index 556beddad533..43c56ba64434 100644
--- a/MdeModulePkg/Core/Pei/PeiMain.h
+++ b/MdeModulePkg/Core/Pei/PeiMain.h
@@ -401,7 +401,7 @@ PeimDispatchReadiness (
   @param PeimFileHandle       Pointer to the FFS file header of the image.
   @param MigratedFileHandle   Pointer to the FFS file header of the migrated image.
 
-  @retval EFI_SUCCESS         Sucessfully migrated the PEIM to permanent memory.
+  @retval EFI_SUCCESS         Successfully migrated the PEIM to permanent memory.
 
 **/
 EFI_STATUS
diff --git a/MdeModulePkg/Core/DxeIplPeim/DxeLoad.c b/MdeModulePkg/Core/DxeIplPeim/DxeLoad.c
index 2c19f1a507ba..4486cf60d706 100644
--- a/MdeModulePkg/Core/DxeIplPeim/DxeLoad.c
+++ b/MdeModulePkg/Core/DxeIplPeim/DxeLoad.c
@@ -59,7 +59,7 @@ CONST EFI_PEI_NOTIFY_DESCRIPTOR  mMemoryDiscoveredNotifyList = {
   @param  FileHandle  Handle of the file being invoked.
   @param  PeiServices Describes the list of possible PEI Services.
 
-  @retval EFI_SUCESS  The entry point of DXE IPL PEIM executes successfully.
+  @retval EFI_SUCCESS The entry point of DXE IPL PEIM executes successfully.
   @retval Others      Some error occurs during the execution of this function.
 
 **/
@@ -80,7 +80,7 @@ PeimInitializeDxeIpl (
     Status = PeiServicesRegisterForShadow (FileHandle);
     if (Status == EFI_SUCCESS) {
       //
       // EFI_SUCESS means it is the first time to call register for shadow.
       //
       return Status;
     }
@@ -80,7 +80,7 @@ PeimInitializeDxeIpl (
     if (Status == EFI_SUCCESS) {
       //
-      // EFI_SUCESS means it is the first time to call register for shadow.
+      // EFI_SUCCESS means it is the first time to call register for shadow.
       //
       return Status;
-- 
2.39.3 (Apple Git-145)



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#111497): https://edk2.groups.io/g/devel/message/111497
Mute This Topic: https://groups.io/mt/102721247/7686176
Group Owner: devel+owner@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [rebecca@openfw.io]
-=-=-=-=-=-=-=-=-=-=-=-



^ permalink raw reply related	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2023-11-21 19:13 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2023-11-21  2:07 [edk2-devel] [PATCH 1/1] MdeModulePkg: Fix typos in Bus and Core Page Chen via groups.io
2023-11-21 16:16 ` Laszlo Ersek
2023-11-21 19:13   ` Page Chen via groups.io

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox